pub struct CborCodec<T> { /* private fields */ }Expand description
Implementation of the tokio codec traits to encode- and decode CBOR data as a stream.
CBOR allows message framing based on initial “headers” for each “data item”, which indicate the type of data and the expected “body” length to be followed. A stream-based decoder can attempt parsing these headers and then reason about if it has enough information to proceed.
Read more on CBOR in streaming applications here: https://www.rfc-editor.org/rfc/rfc8949.html#section-5.1
Implementations