pub struct HybridTimestamp(/* private fields */);Expand description
Hybrid UNIX and logical clock timestamp.
This allows for settings where we want the guarantees of a monotonically incrementing lamport timestamp but still “move forwards” with “global time” so we get the best of both worlds during ordering:
- If we lost the state of our logical clock we will still be after previous timestamps, as the global UNIX time advanced (given that no OS clock was faulty).
- If the UNIX timestamp is the same we know which item came after because of the logical clock and don’t need to rely on more “random” tie-breakers, like a hashing digest.
Implementations
Sourceimpl HybridTimestamp
impl HybridTimestamp
pub fn from_parts(timestamp: Timestamp, logical: LamportTimestamp) -> Self
pub fn now() -> Self
pub fn increment(self) -> Self