pub type NetworkId = [u8; 32];Expand description
Identifier for a network.
The network identifier is used to achieve separation and prevent interoperability between distinct networks. This is the most global identifier to group nodes into networks. Different applications may choose to share the same underlying network infrastructure by using the same network identifier.
A BLAKE3 hash function is performed against each protocol identifier which is registered with
p2panda-net, using the network identifier as an additional input. Even if two instances of
p2panda-net are created with the same network protocols, any communication attempts will fail
if they are not using the same network identifier.
WARNING: The network identifier is not confidentially exchanged with a remote node and can not be treated as a secret value. See: https://github.com/p2panda/p2panda/issues/965