NodeId

Type Alias NodeId 

pub type NodeId = VerifyingKey;
Identifer for a node in the network.

Each node in p2panda has a unique identifier created as a cryptographic key to globally identify it and encrypt network traffic for this node only.

Aliased Type

pub struct NodeId(/* private fields */);